@@ -32,7 +32,6 @@ _xml_namespace_dealloc(void *ptr)
    * node set. see noko_xml_namespace_wrap().
    */
   xmlNsPtr ns = ptr;
-  NOKOGIRI_DEBUG_START(ns) ;
 
   if (ns->href) {
     xmlFree(DISCARD_CONST_QUAL_XMLCHAR(ns->href));
@@ -41,10 +40,8 @@ _xml_namespace_dealloc(void *ptr)
     xmlFree(DISCARD_CONST_QUAL_XMLCHAR(ns->prefix));
   }
   xmlFree(ns);
-  NOKOGIRI_DEBUG_END(ns) ;
 }
 
-#ifdef HAVE_RB_GC_LOCATION
 static void
 _xml_namespace_update_references(void *ptr)
 {
@@ -53,33 +50,45 @@ _xml_namespace_update_references(void *ptr)
     ns->_private = (void *)rb_gc_location((VALUE)ns->_private);
   }
 }
-#else
-#  define _xml_namespace_update_references 0
-#endif
 
-static const rb_data_type_t nokogiri_xml_namespace_type_with_dealloc = {
-  "Nokogiri/XMLNamespace/WithDealloc",
-  {0, _xml_namespace_dealloc, 0, _xml_namespace_update_references},
-  0, 0,
-#ifdef RUBY_TYPED_FREE_IMMEDIATELY
-  RUBY_TYPED_FREE_IMMEDIATELY,
-#endif
+static const rb_data_type_t xml_ns_type_with_free = {
+  .wrap_struct_name = "xmlNs (with free)",
+  .function = {
+    .dfree = _xml_namespace_dealloc,
+    .dcompact = _xml_namespace_update_references,
+  },
+  .flags = RUBY_TYPED_FREE_IMMEDIATELY | RUBY_TYPED_WB_PROTECTED,
 };
 
-static const rb_data_type_t nokogiri_xml_namespace_type_without_dealloc = {
-  "Nokogiri/XMLNamespace/WithoutDealloc",
-  {0, 0, 0, _xml_namespace_update_references},
-  0, 0,
-#ifdef RUBY_TYPED_FREE_IMMEDIATELY
-  RUBY_TYPED_FREE_IMMEDIATELY,
-#endif
+static const rb_data_type_t xml_ns_type_without_free = {
+  .wrap_struct_name = "xmlNs (without free)",
+  .function = {
+    .dcompact = _xml_namespace_update_references,
+  },
+  .flags = RUBY_TYPED_FREE_IMMEDIATELY | RUBY_TYPED_WB_PROTECTED,
 };
 
 /*
- * call-seq:
- *  prefix
+ *  :call-seq:
+ *    prefix() → String or nil
  *
- * Get the prefix for this namespace.  Returns +nil+ if there is no prefix.
+ *  Return the prefix for this Namespace, or +nil+ if there is no prefix (e.g., default namespace).
+ *
+ *  *Example*
+ *
+ *    doc = Nokogiri::XML.parse(<<~XML)
+ *      <?xml version="1.0"?>
+ *      <root xmlns="http://nokogiri.org/ns/default" xmlns:noko="http://nokogiri.org/ns/noko">
+ *        <child1 foo="abc" noko:bar="def"/>
+ *        <noko:child2 foo="qwe" noko:bar="rty"/>
+ *      </root>
+ *    XML
+ *
+ *    doc.root.elements.first.namespace.prefix
+ *    # => nil
+ *
+ *    doc.root.elements.last.namespace.prefix
+ *    # => "noko"
  */
 static VALUE
 prefix(VALUE self)
@@ -93,10 +102,26 @@ prefix(VALUE self)
 }
 
 /*
- * call-seq:
- *  href
+ *  :call-seq:
+ *    href() → String
  *
- * Get the href for this namespace
+ *  Returns the URI reference for this Namespace.
+ *
+ *  *Example*
+ *
+ *    doc = Nokogiri::XML.parse(<<~XML)
+ *      <?xml version="1.0"?>
+ *      <root xmlns="http://nokogiri.org/ns/default" xmlns:noko="http://nokogiri.org/ns/noko">
+ *        <child1 foo="abc" noko:bar="def"/>
+ *        <noko:child2 foo="qwe" noko:bar="rty"/>
+ *      </root>
+ *    XML
+ *
+ *    doc.root.elements.first.namespace.href
+ *    # => "http://nokogiri.org/ns/default"
+ *
+ *    doc.root.elements.last.namespace.href
+ *    # => "http://nokogiri.org/ns/noko"
  */
 static VALUE
 href(VALUE self)
@@ -120,7 +145,7 @@ noko_xml_namespace_wrap(xmlNsPtr c_namespace, xmlDocPtr c_document)
 
   if (c_document) {
     rb_namespace = TypedData_Wrap_Struct(cNokogiriXmlNamespace,
-                                         &nokogiri_xml_namespace_type_without_dealloc,
+                                         &xml_ns_type_without_free,
                                          c_namespace);
 
     if (DOC_RUBY_OBJECT_TEST(c_document)) {
@@ -129,7 +154,7 @@ noko_xml_namespace_wrap(xmlNsPtr c_namespace, xmlDocPtr c_document)
     }
   } else {
     rb_namespace = TypedData_Wrap_Struct(cNokogiriXmlNamespace,
-                                         &nokogiri_xml_namespace_type_with_dealloc,
+                                         &xml_ns_type_with_free,
                                          c_namespace);
   }
 
@@ -145,7 +170,7 @@ noko_xml_namespace_wrap_xpath_copy(xmlNsPtr c_namespace)
 }
 
 void
-noko_init_xml_namespace()
+noko_init_xml_namespace(void)
 {
   cNokogiriXmlNamespace = rb_define_class_under(mNokogiriXml, "Namespace", rb_cObject);
 
