@@ -23,9 +23,10 @@ module Nokogiri
         assert_instance_of(ProcessingInstruction, ref)
       end
 
-      def test_many_new
-        100.times { ProcessingInstruction.new(@xml, "foo", "bar") }
-        @xml.root << ProcessingInstruction.new(@xml, "foo", "bar")
+      def test_rooting_pi
+        refute_raises do
+          @xml.root << ProcessingInstruction.new(@xml, "foo", "bar")
+        end
       end
     end
   end
